[PATCH] D134863: [LLVM][MC] Disable cfi-version test for aarch64-pc-windows*
Muhammad Omair Javaid via Phabricator via llvm-commits
llvm-commits at lists.llvm.org
Thu Sep 29 02:16:24 PDT 2022
omjavaid updated this revision to Diff 463805.
omjavaid added a comment.
As suggested I have accomodated both arm64 and aarch64.
Repository:
rG LLVM Github Monorepo
CHANGES SINCE LAST ACTION
https://reviews.llvm.org/D134863/new/
https://reviews.llvm.org/D134863
Files:
llvm/test/MC/ELF/cfi-version.ll
llvm/test/lit.cfg.py
Index: llvm/test/MC/ELF/cfi-version.ll
===================================================================
--- llvm/test/MC/ELF/cfi-version.ll
+++ llvm/test/MC/ELF/cfi-version.ll
@@ -6,7 +6,7 @@
; PR46647
; XFAIL: arm64-apple
-; .debug_frame is not emitted for targeting Windows x64, arm64, or AIX.
+; .debug_frame is not emitted for targeting Windows x64, aarch64/arm64, or AIX.
; REQUIRES: debug_frame
; REQUIRES: object-emission
-------------- next part --------------
A non-text attachment was scrubbed...
Name: D134863.463805.patch
Type: text/x-patch
Size: 1157 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20220929/c5b5d047/attachment.bin>
More information about the llvm-commits
mailing list
Index: llvm/test/lit.cfg.py
===================================================================
--- llvm/test/lit.cfg.py
+++ llvm/test/lit.cfg.py
@@ -436,8 +436,8 @@
if 'hw.optional.fma: 1' in result:
config.available_features.add('fma3')
-# .debug_frame is not emitted for targeting Windows x64, arm64, or AIX.
-if not re.match(r'^(x86_64|arm64|powerpc|powerpc64).*-(windows-gnu|windows-msvc|aix)', config.target_triple):
+# .debug_frame is not emitted for targeting Windows x64, aarch64, or AIX.
+if not re.match(r'^(x86_64|aarch64|arm64|powerpc|powerpc64).*-(windows-gnu|windows-msvc|aix)', config.target_triple):
config.available_features.add('debug_frame')
if config.have_libxar: